[![Build Status](https://travis-ci.org/uw-it-cte/django-ems-r25.svg?branch=master)](https://travis-ci.org/uw-it-cte/django-ems-r25)
[![Coverage Status](https://coveralls.io/repos/github/uw-it-cte/django-ems-r25/badge.svg?branch=master)](https://coveralls.io/github/uw-it-cte/django-ems-r25?branch=master)

# django-ems-r25
